@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -30,7 +30,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Color(object):
+class Color:
     ''' A base class for representing color objects.
 
     '''
