@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -103,7 +103,7 @@ def generate_jwt_token(session_id: str,
     Returns:
         str
     """
-    now = calendar.timegm(dt.datetime.now().utctimetuple())
+    now = calendar.timegm(dt.datetime.utcnow().utctimetuple())
     payload = {'session_id': session_id, 'session_expiry': now+expiration}
     if extra_payload:
         if "session_id" in extra_payload:
@@ -298,7 +298,7 @@ def _get_random_string(length: int = 44,
     """
     secret_key = _ensure_bytes(secret_key)
     _reseed_if_needed(using_sysrandom, secret_key)
-    return ''.join(random.choice(allowed_chars) for i in range(length))
+    return ''.join(random.choice(allowed_chars) for _ in range(length))
 
 #-----------------------------------------------------------------------------
 # Code
