@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -47,8 +47,8 @@ class HP(HasProps):
     foo = Int(default=10)
     bar = String()
 
-class TestBokehJSONEncoder(object):
 
+class TestBokehJSONEncoder:
     def setup_method(self, test_method):
         from bokeh.core.json_encoder import BokehJSONEncoder
         self.encoder = BokehJSONEncoder()
@@ -151,8 +151,8 @@ class TestBokehJSONEncoder(object):
         ts = pd.Timestamp('April 28, 1948')
         assert self.encoder.default(ts) == -684115200000
 
-class TestSerializeJson(object):
 
+class TestSerializeJson:
     def setup_method(self, test_method):
         from bokeh.core.json_encoder import serialize_json
         from json import loads
@@ -198,16 +198,21 @@ class TestSerializeJson(object):
         serialized = self.serialize({'vals' : df.vals,
                                      'idx' : df.index})
         deserialized = self.deserialize(serialized)
-        baseline = {u'vals': [978307200000,
-                              978393600000,
-                              978480000000,
-                              978566400000,
-                              978652800000],
-                    u'idx': [978307200000,
-                             978393600000,
-                             978480000000,
-                             978566400000,
-                             978652800000]
+        baseline = {
+            "vals": [
+                978307200000,
+                978393600000,
+                978480000000,
+                978566400000,
+                978652800000,
+            ],
+            "idx": [
+                978307200000,
+                978393600000,
+                978480000000,
+                978566400000,
+                978652800000,
+            ],
         }
         assert deserialized == baseline
 
