@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -95,9 +95,9 @@ def test__get_save_args_missing_title(mock_warn) -> None:
     assert mock_warn.call_args[1] == {}
 
 
-@patch('io.open')
-@patch('bokeh.embed.file_html')
-def test__save_helper(mock_file_html, mock_io_open) -> None:
+@patch("builtins.open")
+@patch("bokeh.embed.file_html")
+def test__save_helper(mock_file_html, mock_open) -> None:
     obj = Plot()
     filename, resources, title = bis._get_save_args(curstate(), "filename", "resources", "title")
 
@@ -107,9 +107,9 @@ def test__save_helper(mock_file_html, mock_io_open) -> None:
     assert mock_file_html.call_args[0] == (obj, resources)
     assert mock_file_html.call_args[1] == dict(title="title", template=None, theme=None)
 
-    assert mock_io_open.call_count == 1
-    assert mock_io_open.call_args[0] == (filename,)
-    assert mock_io_open.call_args[1] == dict(mode="w", encoding="utf-8")
+    assert mock_open.call_count == 1
+    assert mock_open.call_args[0] == (filename,)
+    assert mock_open.call_args[1] == dict(mode="w", encoding="utf-8")
 
 #-----------------------------------------------------------------------------
 # Code
