@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -17,6 +17,7 @@ import pytest ; pytest
 # External imports
 import selenium.webdriver.chrome.webdriver
 import selenium.webdriver.firefox.webdriver
+from flaky import flaky
 
 # Module under test
 import bokeh.io.webdriver as biw # isort:skip
@@ -34,6 +35,7 @@ import bokeh.io.webdriver as biw # isort:skip
 #-----------------------------------------------------------------------------
 
 @pytest.mark.selenium
+@flaky(max_runs=10)
 def test_create_firefox_webdriver() -> None:
     d = biw.create_firefox_webdriver()
     try:
@@ -42,6 +44,7 @@ def test_create_firefox_webdriver() -> None:
         d.quit()
 
 @pytest.mark.selenium
+@flaky(max_runs=10)
 def test_create_chromium_webdriver() -> None:
     d = biw.create_chromium_webdriver()
     try:
@@ -54,7 +57,9 @@ _driver_map = {
     "chromium": selenium.webdriver.chrome.webdriver.WebDriver,
 }
 
-class Test_webdriver_control(object):
+@flaky(max_runs=10)
+class Test_webdriver_control:
+
     def test_default(self) -> None:
         # other tests may have interacted with the global biw.webdriver_control,
         # so create a new instance only to check default values
